# -*- coding: utf-8 -*-
idna2003_disallowed = frozenset(
    # prohibited RFC 3454 §C
    [
        0x0020,
        0x00A0,
        0x1680,
        0x2000,
        0x2001,
        0x2002,
        0x2003,
        0x2004,
        0x2005,
        0x2006,
        0x2007,
        0x2008,
        0x2009,
        0x200A,
        0x200B,
        0x202F,
        0x205F,
        0x3000,
        0x007F,
        0x06DD,
        0x070F,
        0x180E,
        0x200C,
        0x200D,
        0x2028,
        0x2029,
        0x2060,
        0x2061,
        0x2062,
        0x2063,
        0xFEFF,
        0xFFF9,
        0xFFFA,
        0xFFFB,
        0xFFFC,
        0xFFFD,
        0x0340,
        0x0341,
        0x200E,
        0x200F,
        0x202A,
        0x202B,
        0x202C,
        0x202D,
        0x202E,
        0x206A,
        0x206B,
        0x206C,
        0x206D,
        0x206E,
        0x206F,
        0xE0001
    ] +
    list(range(0x0000, 0x001F + 1)) +
    list(range(0x0080, 0x009F + 1)) +
    list(range(0x206A, 0x206F + 1)) +
    list(range(0xFFF9, 0xFFFC + 1)) +
    list(range(0x1D173, 0x1D17A + 1)) +
    list(range(0xE000, 0xF8FF + 1)) +
    list(range(0xF0000, 0xFFFFD + 1)) +
    list(range(0x100000, 0x10FFFD + 1)) +
    list(range(0xFDD0, 0xFDEF + 1)) +
    list(range(0xFFFE, 0xFFFF + 1)) +
    list(range(0x1FFFE, 0x1FFFF + 1)) +
    list(range(0x2FFFE, 0x2FFFF + 1)) +
    list(range(0x3FFFE, 0x3FFFF + 1)) +
    list(range(0x4FFFE, 0x4FFFF + 1)) +
    list(range(0x5FFFE, 0x5FFFF + 1)) +
    list(range(0x6FFFE, 0x6FFFF + 1)) +
    list(range(0x7FFFE, 0x7FFFF + 1)) +
    list(range(0x8FFFE, 0x8FFFF + 1)) +
    list(range(0x9FFFE, 0x9FFFF + 1)) +
    list(range(0xAFFFE, 0xAFFFF + 1)) +
    list(range(0xBFFFE, 0xBFFFF + 1)) +
    list(range(0xCFFFE, 0xCFFFF + 1)) +
    list(range(0xDFFFE, 0xDFFFF + 1)) +
    list(range(0xEFFFE, 0xEFFFF + 1)) +
    list(range(0xFFFFE, 0xFFFFF + 1)) +
    list(range(0x10FFFE, 0x10FFFF + 1)) +
    list(range(0xD800, 0xDFFF + 1)) +
    list(range(0x2FF0, 0x2FFB + 1)) +
    list(range(0xE0020, 0xE007F + 1)) +
    # unassigned RFC 3454 §A
    [
        0x0221,
        0x038B,
        0x038D,
        0x03A2,
        0x03CF,
        0x0487,
        0x04CF,
        0x0560,
        0x0588,
        0x05A2,
        0x05BA,
        0x0620,
        0x06FF,
        0x070E,
        0x09BD,
        0x09A9,
        0x09B1,
        0x0904,
        0x0984,
        0x09DE,
        0x0A29,
        0x0A31,
        0x0A34,
        0x0A37,
        0x0A3D,
        0x0A5D,
        0x0A84,
        0x0A8C,
        0x0A8E,
        0x0A92,
        0x0AA9,
        0x0AB1,
        0x0AB4,
        0x0AC6,
        0x0ACA,
        0x0B04,
        0x0B29,
        0x0B31,
        0x0B5E,
        0x0B84,
        0x0B91,
        0x0B9B,
        0x0B9D,
        0x0BB6,
        0x0BC9,
        0x0C04,
        0x0C0D,
        0x0C11,
        0x0C29,
        0x0C34,
        0x0C45,
        0x0C49,
        0x0C84,
        0x0C8D,
        0x0C91,
        0x0CA9,
        0x0CB4,
        0x0CC5,
        0x0CC9,
        0x0CDF,
        0x0D04,
        0x0D0D,
        0x0D11,
        0x0D29,
        0x0D49,
        0x0D84,
        0x0DB2,
        0x0DBC,
        0x0DD5,
        0x0DD7,
        0x0E83,
        0x0E89,
        0x0E98,
        0x0EA0,
        0x0EA4,
        0x0EA6,
        0x0EAC,
        0x0EBA,
        0x0EC5,
        0x0EC7,
        0x0F48,
        0x0F98,
        0x0FBD,
        0x1022,
        0x1028,
        0x102B,
        0x1207,
        0x1247,
        0x1249,
        0x1257,
        0x1259,
        0x1287,
        0x1289,
        0x12AF,
        0x12B1,
        0x12BF,
        0x12C1,
        0x12CF,
        0x12D7,
        0x12EF,
        0x130F,
        0x1311,
        0x131F,
        0x1347,
        0x170D,
        0x176D,
        0x1771,
        0x180F,
        0x1F58,
        0x1F5A,
        0x1F5C,
        0x1F5E,
        0x1FB5,
        0x1FC5,
        0x1FDC,
        0x1FF5,
        0x1FFF,
        0x24FF,
        0x2618,
        0x2705,
        0x2728,
        0x274C,
        0x274E,
        0x2757,
        0x27B0,
        0x2E9A,
        0x3040,
        0x318F,
        0x33FF,
        0xFB37,
        0xFB3D,
        0xFB3F,
        0xFB42,
        0xFB45,
        0xFE53,
        0xFE67,
        0xFE75,
        0xFF00,
        0xFFE7,
        0x1031F,
        0x1D455,
        0x1D49D,
        0x1D4AD,
        0x1D4BA,
        0x1D4BC,
        0x1D4C1,
        0x1D4C4,
        0x1D506,
        0x1D515,
        0x1D51D,
        0x1D53A,
        0x1D53F,
        0x1D545,
        0x1D551,
        0xE0000
    ] +
    list(range(0x0234, 0x024F + 1)) +
    list(range(0x02AE, 0x02AF + 1)) +
    list(range(0x02EF, 0x02FF + 1)) +
    list(range(0x0350, 0x035F + 1)) +
    list(range(0x0370, 0x0373 + 1)) +
    list(range(0x0376, 0x0379 + 1)) +
    list(range(0x037B, 0x037D + 1)) +
    list(range(0x037F, 0x0383 + 1)) +
    list(range(0x03F7, 0x03FF + 1)) +
    list(range(0x04F6, 0x04F7 + 1)) +
    list(range(0x04FA, 0x04FF + 1)) +
    list(range(0x0510, 0x0530 + 1)) +
    list(range(0x0557, 0x0558 + 1)) +
    list(range(0x058B, 0x0590 + 1)) +
    list(range(0x05C5, 0x05CF + 1)) +
    list(range(0x05EB, 0x05EF + 1)) +
    list(range(0x05F5, 0x060B + 1)) +
    list(range(0x060D, 0x061A + 1)) +
    list(range(0x061C, 0x061E + 1)) +
    list(range(0x063B, 0x063F + 1)) +
    list(range(0x0656, 0x065F + 1)) +
    list(range(0x06EE, 0x06EF + 1)) +
    list(range(0x072D, 0x072F + 1)) +
    list(range(0x074B, 0x077F + 1)) +
    list(range(0x07B2, 0x0900 + 1)) +
    list(range(0x093A, 0x093B + 1)) +
    list(range(0x094E, 0x094F + 1)) +
    list(range(0x0955, 0x0957 + 1)) +
    list(range(0x0971, 0x0980 + 1)) +
    list(range(0x098D, 0x098E + 1)) +
    list(range(0x0991, 0x0992 + 1)) +
    list(range(0x09B3, 0x09B5 + 1)) +
    list(range(0x09BA, 0x09BB + 1)) +
    list(range(0x09C5, 0x09C6 + 1)) +
    list(range(0x09C9, 0x09CA + 1)) +
    list(range(0x09CE, 0x09D6 + 1)) +
    list(range(0x09D8, 0x09DB + 1)) +
    list(range(0x09E4, 0x09E5 + 1)) +
    list(range(0x09FB, 0x0A01 + 1)) +
    list(range(0x0A03, 0x0A04 + 1)) +
    list(range(0x0A0B, 0x0A0E + 1)) +
    list(range(0x0A11, 0x0A12 + 1)) +
    list(range(0x0A3A, 0x0A3B + 1)) +
    list(range(0x0A43, 0x0A46 + 1)) +
    list(range(0x0A49, 0x0A4A + 1)) +
    list(range(0x0A4E, 0x0A58 + 1)) +
    list(range(0x0A5F, 0x0A65 + 1)) +
    list(range(0x0A75, 0x0A80 + 1)) +
    list(range(0x0ABA, 0x0ABB + 1)) +
    list(range(0x0ACE, 0x0ACF + 1)) +
    list(range(0x0AD1, 0x0ADF + 1)) +
    list(range(0x0AE1, 0x0AE5 + 1)) +
    list(range(0x0AF0, 0x0B00 + 1)) +
    list(range(0x0B0D, 0x0B0E + 1)) +
    list(range(0x0B11, 0x0B12 + 1)) +
    list(range(0x0B34, 0x0B35 + 1)) +
    list(range(0x0B3A, 0x0B3B + 1)) +
    list(range(0x0B44, 0x0B46 + 1)) +
    list(range(0x0B49, 0x0B4A + 1)) +
    list(range(0x0B4E, 0x0B55 + 1)) +
    list(range(0x0B58, 0x0B5B + 1)) +
    list(range(0x0B62, 0x0B65 + 1)) +
    list(range(0x0B71, 0x0B81 + 1)) +
    list(range(0x0B8B, 0x0B8D + 1)) +
    list(range(0x0B96, 0x0B98 + 1)) +
    list(range(0x0BA0, 0x0BA2 + 1)) +
    list(range(0x0BA5, 0x0BA7 + 1)) +
    list(range(0x0BAB, 0x0BAD + 1)) +
    list(range(0x0BBA, 0x0BBD + 1)) +
    list(range(0x0BC3, 0x0BC5 + 1)) +
    list(range(0x0BCE, 0x0BD6 + 1)) +
    list(range(0x0BD8, 0x0BE6 + 1)) +
    list(range(0x0BF3, 0x0C00 + 1)) +
    list(range(0x0C3A, 0x0C3D + 1)) +
    list(range(0x0C4E, 0x0C54 + 1)) +
    list(range(0x0C57, 0x0C5F + 1)) +
    list(range(0x0C62, 0x0C65 + 1)) +
    list(range(0x0C70, 0x0C81 + 1)) +
    list(range(0x0CBA, 0x0CBD + 1)) +
    list(range(0x0CCE, 0x0CD4 + 1)) +
    list(range(0x0CD7, 0x0CDD + 1)) +
    list(range(0x0CE2, 0x0CE5 + 1)) +
    list(range(0x0CF0, 0x0D01 + 1)) +
    list(range(0x0D3A, 0x0D3D + 1)) +
    list(range(0x0D44, 0x0D45 + 1)) +
    list(range(0x0D4E, 0x0D56 + 1)) +
    list(range(0x0D58, 0x0D5F + 1)) +
    list(range(0x0D62, 0x0D65 + 1)) +
    list(range(0x0D70, 0x0D81 + 1)) +
    list(range(0x0D97, 0x0D99 + 1)) +
    list(range(0x0DBE, 0x0DBF + 1)) +
    list(range(0x0DC7, 0x0DC9 + 1)) +
    list(range(0x0DCB, 0x0DCE + 1)) +
    list(range(0x0DE0, 0x0DF1 + 1)) +
    list(range(0x0DF5, 0x0E00 + 1)) +
    list(range(0x0E3B, 0x0E3E + 1)) +
    list(range(0x0E5C, 0x0E80 + 1)) +
    list(range(0x0E85, 0x0E86 + 1)) +
    list(range(0x0E8B, 0x0E8C + 1)) +
    list(range(0x0E8E, 0x0E93 + 1)) +
    list(range(0x0EA8, 0x0EA9 + 1)) +
    list(range(0x0EBE, 0x0EBF + 1)) +
    list(range(0x0ECE, 0x0ECF + 1)) +
    list(range(0x0EDA, 0x0EDB + 1)) +
    list(range(0x0EDE, 0x0EFF + 1)) +
    list(range(0x0F6B, 0x0F70 + 1)) +
    list(range(0x0F8C, 0x0F8F + 1)) +
    list(range(0x0FCD, 0x0FCE + 1)) +
    list(range(0x0FD0, 0x0FFF + 1)) +
    list(range(0x1033, 0x1035 + 1)) +
    list(range(0x103A, 0x103F + 1)) +
    list(range(0x105A, 0x109F + 1)) +
    list(range(0x10C6, 0x10CF + 1)) +
    list(range(0x10F9, 0x10FA + 1)) +
    list(range(0x10FC, 0x10FF + 1)) +
    list(range(0x115A, 0x115E + 1)) +
    list(range(0x11A3, 0x11A7 + 1)) +
    list(range(0x11FA, 0x11FF + 1)) +
    list(range(0x124E, 0x124F + 1)) +
    list(range(0x125E, 0x125F + 1)) +
    list(range(0x128E, 0x128F + 1)) +
    list(range(0x12B6, 0x12B7 + 1)) +
    list(range(0x12C6, 0x12C7 + 1)) +
    list(range(0x1316, 0x1317 + 1)) +
    list(range(0x135B, 0x1360 + 1)) +
    list(range(0x137D, 0x139F + 1)) +
    list(range(0x13F5, 0x1400 + 1)) +
    list(range(0x1677, 0x167F + 1)) +
    list(range(0x169D, 0x169F + 1)) +
    list(range(0x16F1, 0x16FF + 1)) +
    list(range(0x1715, 0x171F + 1)) +
    list(range(0x1737, 0x173F + 1)) +
    list(range(0x1754, 0x175F + 1)) +
    list(range(0x1774, 0x177F + 1)) +
    list(range(0x17DD, 0x17DF + 1)) +
    list(range(0x17EA, 0x17FF + 1)) +
    list(range(0x181A, 0x181F + 1)) +
    list(range(0x1878, 0x187F + 1)) +
    list(range(0x18AA, 0x1DFF + 1)) +
    list(range(0x1E9C, 0x1E9F + 1)) +
    list(range(0x1EFA, 0x1EFF + 1)) +
    list(range(0x1F16, 0x1F17 + 1)) +
    list(range(0x1F1E, 0x1F1F + 1)) +
    list(range(0x1F46, 0x1F47 + 1)) +
    list(range(0x1F4E, 0x1F4F + 1)) +
    list(range(0x1F7E, 0x1F7F + 1)) +
    list(range(0x1FD4, 0x1FD5 + 1)) +
    list(range(0x1FF0, 0x1FF1 + 1)) +
    list(range(0x2053, 0x2056 + 1)) +
    list(range(0x2058, 0x205E + 1)) +
    list(range(0x2064, 0x2069 + 1)) +
    list(range(0x2072, 0x2073 + 1)) +
    list(range(0x208F, 0x209F + 1)) +
    list(range(0x20B2, 0x20CF + 1)) +
    list(range(0x20EB, 0x20FF + 1)) +
    list(range(0x213B, 0x213C + 1)) +
    list(range(0x214C, 0x2152 + 1)) +
    list(range(0x2184, 0x218F + 1)) +
    list(range(0x23CF, 0x23FF + 1)) +
    list(range(0x2427, 0x243F + 1)) +
    list(range(0x244B, 0x245F + 1)) +
    list(range(0x2614, 0x2615 + 1)) +
    list(range(0x267E, 0x267F + 1)) +
    list(range(0x268A, 0x2700 + 1)) +
    list(range(0x270A, 0x270B + 1)) +
    list(range(0x2753, 0x2755 + 1)) +
    list(range(0x275F, 0x2760 + 1)) +
    list(range(0x2795, 0x2797 + 1)) +
    list(range(0x27BF, 0x27CF + 1)) +
    list(range(0x27EC, 0x27EF + 1)) +
    list(range(0x2B00, 0x2E7F + 1)) +
    list(range(0x2EF4, 0x2EFF + 1)) +
    list(range(0x2FD6, 0x2FEF + 1)) +
    list(range(0x2FFC, 0x2FFF + 1)) +
    list(range(0x3097, 0x3098 + 1)) +
    list(range(0x3100, 0x3104 + 1)) +
    list(range(0x312D, 0x3130 + 1)) +
    list(range(0x31B8, 0x31EF + 1)) +
    list(range(0x321D, 0x321F + 1)) +
    list(range(0x3244, 0x3250 + 1)) +
    list(range(0x327C, 0x327E + 1)) +
    list(range(0x32CC, 0x32CF + 1)) +
    list(range(0x3377, 0x337A + 1)) +
    list(range(0x33DE, 0x33DF + 1)) +
    list(range(0x4DB6, 0x4DFF + 1)) +
    list(range(0x9FA6, 0x9FFF + 1)) +
    list(range(0xA48D, 0xA48F + 1)) +
    list(range(0xA4C7, 0xABFF + 1)) +
    list(range(0xD7A4, 0xD7FF + 1)) +
    list(range(0xFA2E, 0xFA2F + 1)) +
    list(range(0xFA6B, 0xFAFF + 1)) +
    list(range(0xFB07, 0xFB12 + 1)) +
    list(range(0xFB18, 0xFB1C + 1)) +
    list(range(0xFBB2, 0xFBD2 + 1)) +
    list(range(0xFD40, 0xFD4F + 1)) +
    list(range(0xFD90, 0xFD91 + 1)) +
    list(range(0xFDC8, 0xFDCF + 1)) +
    list(range(0xFDFD, 0xFDFF + 1)) +
    list(range(0xFE10, 0xFE1F + 1)) +
    list(range(0xFE24, 0xFE2F + 1)) +
    list(range(0xFE47, 0xFE48 + 1)) +
    list(range(0xFE6C, 0xFE6F + 1)) +
    list(range(0xFEFD, 0xFEFE + 1)) +
    list(range(0xFFBF, 0xFFC1 + 1)) +
    list(range(0xFFC8, 0xFFC9 + 1)) +
    list(range(0xFFD0, 0xFFD1 + 1)) +
    list(range(0xFFD8, 0xFFD9 + 1)) +
    list(range(0xFFDD, 0xFFDF + 1)) +
    list(range(0xFFEF, 0xFFF8 + 1)) +
    list(range(0x10000, 0x102FF + 1)) +
    list(range(0x10324, 0x1032F + 1)) +
    list(range(0x1034B, 0x103FF + 1)) +
    list(range(0x10426, 0x10427 + 1)) +
    list(range(0x1044E, 0x1CFFF + 1)) +
    list(range(0x1D0F6, 0x1D0FF + 1)) +
    list(range(0x1D127, 0x1D129 + 1)) +
    list(range(0x1D1DE, 0x1D3FF + 1)) +
    list(range(0x1D4A0, 0x1D4A1 + 1)) +
    list(range(0x1D4A3, 0x1D4A4 + 1)) +
    list(range(0x1D4A7, 0x1D4A8 + 1)) +
    list(range(0x1D50B, 0x1D50C + 1)) +
    list(range(0x1D547, 0x1D549 + 1)) +
    list(range(0x1D6A4, 0x1D6A7 + 1)) +
    list(range(0x1D7CA, 0x1D7CD + 1)) +
    list(range(0x1D800, 0x1FFFD + 1)) +
    list(range(0x2A6D7, 0x2F7FF + 1)) +
    list(range(0x2FA1E, 0x2FFFD + 1)) +
    list(range(0x30000, 0x3FFFD + 1)) +
    list(range(0x40000, 0x4FFFD + 1)) +
    list(range(0x50000, 0x5FFFD + 1)) +
    list(range(0x60000, 0x6FFFD + 1)) +
    list(range(0x70000, 0x7FFFD + 1)) +
    list(range(0x80000, 0x8FFFD + 1)) +
    list(range(0x90000, 0x9FFFD + 1)) +
    list(range(0xA0000, 0xAFFFD + 1)) +
    list(range(0xB0000, 0xBFFFD + 1)) +
    list(range(0xC0000, 0xCFFFD + 1)) +
    list(range(0xD0000, 0xDFFFD + 1)) +
    list(range(0xE0002, 0xE001F + 1)) +
    list(range(0xE0080, 0xEFFFD + 1)) +
    # others from https://util.unicode.org/UnicodeJsps/list-unicodeset.jsp?a=[:idna2003=disallowed:]
    [
        0x21,
        0x22,
        0x23,
        0x24,
        0x25,
        0x26,
        0x27,
        0x28,
        0x29,
        0x2a,
        0x2b,
        0x2c,
        0x2f,
        0x3a,
        0x3b,
        0x3c,
        0x3d,
        0x3e,
        0x3f,
        0x40,
        0x5b,
        0x5c,
        0x5d,
        0x5e,
        0x5f,
        0x60,
        0x7b,
        0x7c,
        0x7d,
        0x7e,
        0xa8,
        0xaf,
        0xb4,
        0xb8,
        0x2d8,
        0x2d9,
        0x2da,
        0x2db,
        0x2dc,
        0x2dd,
        0x37a,
        0x37e,
        0x384,
        0x385,
        0x1fbd,
        0x1fbf,
        0x1fc0,
        0x1fc1,
        0x1fcd,
        0x1fce,
        0x1fcf,
        0x1fdd,
        0x1fde,
        0x1fdf,
        0x1fed,
        0x1fee,
        0x1fef,
        0x1ffd,
        0x1ffe,
        0x2017,
        0x2024,
        0x2025,
        0x2026,
        0x203c,
        0x203e,
        0x2047,
        0x2048,
        0x2049,
        0x207a,
        0x207c,
        0x207d,
        0x207e,
        0x208a,
        0x208c,
        0x208d,
        0x208e,
        0x2100,
        0x2101,
        0x2105,
        0x2106,
        0x2474,
        0x2475,
        0x2476,
        0x2477,
        0x2478,
        0x2479,
        0x247a,
        0x247b,
        0x247c,
        0x247d,
        0x247e,
        0x247f,
        0x2480,
        0x2481,
        0x2482,
        0x2483,
        0x2484,
        0x2485,
        0x2486,
        0x2487,
        0x2488,
        0x2489,
        0x248a,
        0x248b,
        0x248c,
        0x248d,
        0x248e,
        0x248f,
        0x2490,
        0x2491,
        0x2492,
        0x2493,
        0x2494,
        0x2495,
        0x2496,
        0x2497,
        0x2498,
        0x2499,
        0x249a,
        0x249b,
        0x249c,
        0x249d,
        0x249e,
        0x249f,
        0x24a0,
        0x24a1,
        0x24a2,
        0x24a3,
        0x24a4,
        0x24a5,
        0x24a6,
        0x24a7,
        0x24a8,
        0x24a9,
        0x24aa,
        0x24ab,
        0x24ac,
        0x24ad,
        0x24ae,
        0x24af,
        0x24b0,
        0x24b1,
        0x24b2,
        0x24b3,
        0x24b4,
        0x24b5,
        0x2a74,
        0x2a75,
        0x2a76,
        0x309b,
        0x309c,
        0x3200,
        0x3201,
        0x3202,
        0x3203,
        0x3204,
        0x3205,
        0x3206,
        0x3207,
        0x3208,
        0x3209,
        0x320a,
        0x320b,
        0x320c,
        0x320d,
        0x320e,
        0x320f,
        0x3210,
        0x3211,
        0x3212,
        0x3213,
        0x3214,
        0x3215,
        0x3216,
        0x3217,
        0x3218,
        0x3219,
        0x321a,
        0x321b,
        0x321c,
        0x3220,
        0x3221,
        0x3222,
        0x3223,
        0x3224,
        0x3225,
        0x3226,
        0x3227,
        0x3228,
        0x3229,
        0x322a,
        0x322b,
        0x322c,
        0x322d,
        0x322e,
        0x322f,
        0x3230,
        0x3231,
        0x3232,
        0x3233,
        0x3234,
        0x3235,
        0x3236,
        0x3237,
        0x3238,
        0x3239,
        0x323a,
        0x323b,
        0x323c,
        0x323d,
        0x323e,
        0x323f,
        0x3240,
        0x3241,
        0x3242,
        0x3243,
        0x32ff,
        0x33c2,
        0x33c7,
        0x33d8,
        0xfb29,
        0xfc5e,
        0xfc5f,
        0xfc60,
        0xfc61,
        0xfc62,
        0xfc63,
        0xfdfa,
        0xfdfb,
        0xfe30,
        0xfe33,
        0xfe34,
        0xfe35,
        0xfe36,
        0xfe37,
        0xfe38,
        0xfe49,
        0xfe4a,
        0xfe4b,
        0xfe4c,
        0xfe4d,
        0xfe4e,
        0xfe4f,
        0xfe50,
        0xfe52,
        0xfe54,
        0xfe55,
        0xfe56,
        0xfe57,
        0xfe59,
        0xfe5a,
        0xfe5b,
        0xfe5c,
        0xfe5f,
        0xfe60,
        0xfe61,
        0xfe62,
        0xfe64,
        0xfe65,
        0xfe66,
        0xfe68,
        0xfe69,
        0xfe6a,
        0xfe6b,
        0xfe70,
        0xfe72,
        0xfe74,
        0xfe76,
        0xfe78,
        0xfe7a,
        0xfe7c,
        0xfe7e,
        0xff01,
        0xff02,
        0xff03,
        0xff04,
        0xff05,
        0xff06,
        0xff07,
        0xff08,
        0xff09,
        0xff0a,
        0xff0b,
        0xff0c,
        0xff0f,
        0xff1a,
        0xff1b,
        0xff1c,
        0xff1d,
        0xff1e,
        0xff1f,
        0xff20,
        0xff3b,
        0xff3c,
        0xff3d,
        0xff3e,
        0xff3f,
        0xff40,
        0xff5b,
        0xff5c,
        0xff5d,
        0xff5e,
        0xffe,
    ])